#In the name of GOD
#----------------------------------------------------------------------
# This file was generated by img2py.py
#----------------------------------------------------------------------

from wx.lib.embeddedimage import PyEmbeddedImage

accept_button = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAmpJREFUeNqkU01oE1EQ/t52E5PNj01BSqlWyLXeWgvGggpF'
    b'RAo96c2TImgRKc1B8OLBQ9GmIFVPemlBwYKgFKRQFLyI+bGaUtHYWCzW1ND8NnbT7J/zdpNN'
    b'td4cmH3wZr5vvp2ZxwzDwP+YyD+MMfvi9Dh6VA1juo4BTs0jggC0CJgnvzY7ikQjlxdn5qdO'
    b'cOoW7gW8/svnjl1E98FDUJQKivI6fhZXkVx5j9jyEmqKNjMbxtldBAR+0tnWcebu+Wkk16bw'
    b'4dsUVJ2ro+rkLkcQFdmHV8lFyDX9PikZtgkGI6zH55Lidy5M4+WnYeQr66ZsUxdryLW8UGxD'
    b'LJWHZqD3+YiREHhQUXF78PAQFn88QI4kC9QZ1mI5KEOlQ9aASyEDDlce7QFA1zAOK2zaiWD7'
    b'ASznXpiya+RUAXRApbNKDCP91rRcEuD3mMqO21PgoapWxjYhroasxMgbBgfR16hyuL85atFh'
    b'TgSN6QvWGIHyr6wluW6jRwxsUuVwqAmeeMsginZbmgQC3eTKGTiJPRJvhq8fbYIjMQb3HgIT'
    b'QtMZGqtjEmjbiH7JpKFXW+FxUfI79se2RRIW2OEESgWGzS3qTRVRuwcbHzH22Zd96nHvxb4u'
    b'wEskk0kGvb4HEgfT72kKkM0CmYKBLGFsBQuPMVfewMxCuoSVlIBKHnBTNS9120Ndd1KZUo7h'
    b'a4ohnTFQ4bmPMGf2b8cqd528gYdSKwY6Agw+ydpA8xepFVw2r8zB8zcRpuvVXW+BLNg9hND+'
    b'XlwR3ehrjIqHVRnR73FMLj3Daw7+52OqG9VGJ7n/r5dbJl8j39r5Gn8LMAAV2Qj37wA9/gAA'
    b'AABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

add = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAlxJREFUeNqkU0toU1EQPfc2bZKHSRpLaUu0YMGNXbYVEfxh'
    b'EZFCV3UnCIqCRUTsIgsXLlyEWhdaFRcKSnZ2pRTclC7EhYa0kErFQrQgjQn5NE3S5vs+nXn5'
    b'FVNw4YV53Hfnzjkzc+YKwzDwP8vCHyFE4+DSDIZUDT5dxyhDs0dKoE1igcw7fw9L9btMLsxP'
    b'DeDiNJ67DzhvXTlzA8f6B1FWc9jKR5HIbCC0HkIwvIpyRZubn8LlFgAKfuc52Dfx7JofK5G3'
    b'WF73o6RydoCV8lQ6BrBTdGExtIJCWXtBmUw2AMYeiyGHTQk+ue7H4o9JpLZjUHXgzqlqf55+'
    b'FrARiBTtSKa78HUtBk3H8Ie7xpLkCxUVj8ZGxvHtzyukCjEqGNCbbYHGRv9GWwV2ZRO9bvJr'
    b'mGGfrN05d6TnMMLJjyZzmSJKehOA90Uqh0uyK2U4FbO7ZxsqcKIlbYvq7MTNkXSLVN7TTalf'
    b'LgtTlbr6siojkNlJQFjkv4WX+8yBJIBUNgrVsYlZYuAyOF3viSqN74swlWin3lgJgGYE9dEx'
    b'8bQSAuHoLxhFN2xWqpPM2tFk4T2fsS+bAXJ5Iiki0ABIfodvLRJHMqHD0CUszGZpAvCezzTK'
    b'Kh4XiKYNxCnGLL82SMr5+3jj6sbEUY9Ed48ORxfgsvWaAJliDLkUBccEfkYNZOKYW3iIqxSb'
    b'3zvK/Rce4LXSidE+t4DDbjTq5I7nClXm7aQZPEXHv1veAq2BwXGcPDSM2xY7jtelYrdaQGAj'
    b'iNnV9/jEwfs+ptriMfGQOf8SMEsWIcvvfY27AgwA3EwHS5LUr7EAAAAASUVORK5CYII=')

#------------------------------------------------------------------------------------------------

application_add = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAepJREFUeNqUkjFIW1EUhv9z733mvac2aOJQ0hrUQlEIgpam'
    b'dhCHIp1cipisFbp0aWvADjqpdGjExU0hq5B2cbQuQkNBsYOCWUTFwQyCiGI6xPdez30aothG'
    b'vXCG+975/vtz/kOPppZyJcd96Xke7nqICIYUC1JQUml4cuA5HNeFuAPsckkhMLa4mhAkk+qc'
    b'wZCpkFrah2IFqgJrj+eskO5vhuZq+EkW8NBgGngaroMkba+KACs4XLpfc/quSqzYFzW5orjP'
    b'0Zw+yr0cXj6/xRZvt0Dc1d7eAc1pUpX/1dp18P4Dk/9d+POpdEgWkBUB27Z4wjcFiEEhFMdm'
    b'QZEBUW6hIM+hBqocv2mZbOsmLoUBywhg/tdbLG5m/Kg5NHSFB9EZyl5xYFm8C9cVOGdIzjbz'
    b'8x3WCxkM9AI9kRGsFaaR387i6BizomxJSLZpGNdKw/p8+z2HWCtwVgRioTROzoAnj/0k3gte'
    b'yVsjCxhAnF/++OLC4Ye4h2cPR/09oPrUwgrZD3p5pf8xAz3pRiTb4oi1AcUSMP7Kw8QywWbR'
    b'jR2O8TSdGObOYDUHxRk5uXvgvI6EgdzeZ548sHMA/DnCd4p++VFl9yVKThCFse6WoWl8DTTg'
    b'jW+bLuBsCp/oHtvbzNV05X7Itf9XgAEAdUyeqmc4PvoAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

application_delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAeZJREFUeNqUkr9rU1EUx7/n3vte3ksaRK2L2AQXSxxcChIE'
    b'oUXRDhIUJ/8GB0EyCoK0OOhQRAXp1kUUsohSaRYdXAQpCLUuClYQ8UehgdLWJvf6PabVFtO0'
    b'vXCGl3s+3/vN+R45NDr1arXlT4QQsNMjIoiseWGNDDmFRyrH0fIeZgewZ1ljcO3J60EjFq5J'
    b'cH/iUJ2ag6OCdIHVY5MKt88UoFzMJykQsDeJ0N/bAytqr4sAFVos7VdOv90qFQeLCauI3Rzl'
    b'9Di/NrzZ2Xe0uL0FYVepdBTKKenW73LZHoQtYJ26CisuaD8dxMCz/gpksymvpBMNsQ4SxUAU'
    b'wZh2z0omhwZ/c+vxJ2lCWx14R4h3X8Zu4OfDcRhrkWFa1dIFXPk8ucFBmnIXNisI81bg051R'
    b'4OUzlCsVuqAT38S+mbeYd7m7bs0RGx2r8+y+TtxDeegkwsIPBOYvFO3rO4hv8wuXHVdy28ji'
    b'OIKcOg8MX/o3pfpj+OkZuNQvvdlzfXKAK/3fDAL/wq9MHu+TGKH2AM1H9+HZZ/io6EDpRAWP'
    b'sPLdHDw9OzDSn5rhQt7+2QON8+Mi8KGxXJPizfqWYIs5NxzjqpYPPz997FZvml5s7wLnsrxS'
    b'O1efviq72N4C68CG7++sud8CDACp8J9A4CbcpgAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

application_edit = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAkFJREFUeNqUUk1oE0EYfTM7k+xuk2qIF0trtIriQZQatfZg'
    b'KkJFjDkpHsSCCIIXqdBT6dGgYPFisQe1GiFFRQRTT/GgEStiLXhKL4o/VK1SamqNtWyy4zcl'
    b'0VqTUgfeMszOe9/7vnmsPp4ecopui1IKS12MMcwU3MGAJWNCk8/EtqPouuBLILsEg3N0p54f'
    b'0DVFgYhBU6Az/R6CFNgiZO2xQAo9baugeR4qSQIKAVNiwwofDKbtLSJACkVCwPLA0Xs6Ew4p'
    b'toZMQgj/s75pN+RXuKXhjY5myWJlC+UTRr0bHgPOtdd4Y0m40zmI8qUa2wdVxb+eOucGhBS4'
    b'm7qHfVv2YPzTBKz8tPotYNsWTbiCAOPghqTKFpLJAcSiUSQGrmPbZBNk7jN4+flNy4Rpev+G'
    b'ZcH2+WEH/Mh2r8GRiI2rN26huWkHHvI0wn0nw8zbdV/9jO+HWyxQFtSfnqlfZhgwaJs5vRaR'
    b'Qw3A2DtkjXb0D/3AxWAUXqloLCXX3BCQUs5BaJTIjzoaibwa+DgB5HJ4kkqg58J5SGcWfirK'
    b'pVE9f5lTDWg9WA98GAemviAxXIcTibdz/wR0cund/J03M8yu3UWRhu5AD9JRJp6uv4OdbZSN'
    b'yRngWS+SL0M4WncFpvMVHuXAzeceB4LBiG5gHWHZwuq344df1DZuxN7Ny9Hfm8TxS8PhBVem'
    b'QmcfvGL0mZd1hlnuRdfYOeRUjRLOd+xuDqHlWF94sGPTSPvKy/C5ebLu/hOySmvrvP1ItUu/'
    b'BBgASa3Cu6z82mEAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

application_form = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAa9JREFUeNqck7tKA0EUhv+5bGIheCkEiWgKu0SNNoJgYoiC'
    b'MQn4NKltbHwaURAREzWFICgoWPgCFlHxUtiYZNZzZjYma1TU2Z1lmZnvP3P+MyPGNg92Gi1T'
    b'avk+AO6/aQJKCHhK7uo3grfW50EifxIgGOXtsxILID7ch63TWx7n98fmB5/yQgzM6iYFzowa'
    b'ZEoj6MHFdwrUIgbMamMHBS6ubwiQXSw9slfBZ6+MwdxsAszq9oQX6SNAO4gW8bqry3ML+MaF'
    b'dYICqZnZD8GOgPZwWDmEkhKGoNzyCmLjcWTTi6EdVE9qkEp2CQTVU1piNZ+3UTiioW2mksme'
    b'FFJTU7i/q6PNaT9whiP7wmYOSFfnx+dnPDw92ZRcDnYWmnbLjB9OgX6lgmShAKhWKx3jLO9M'
    b'zWWzX3jgRbC3v28XMbCWL2BsIo7cUiaUQuXomILoTwIECKVQKBbJAxk4bzCdSPR4ME2+tJqN'
    b'j7S0cJVBVCvYaongBCkWMriv10MpcI962p1a6trj2hI81B/9dBV+uBfCMcxq8/pSG9w4Tjc4'
    b'/O/vkoWZ5Q1PUh/A/9rLuwADAK8loV8tdNaPAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

application_lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAjFJREFUeNqUU0toE1EUPe/Nm2RmOq0dPwVpbBYqoosEWlAQ'
    b'seIi1EqL4MKtC0Hdxy4kKoVCwe+uCi7dqAsLTVDRKPgFxY1GjQ1KtGqLxKY1jQlxJvO8E1uF'
    b'2Nb64Czm3rnnnnfufazp+PURXfAeKSWWehhjKDtu3NLVXuEVD/RuRtV1wZdQ7BIUzhEbedrj'
    b'9RQOFa7QBKK3xiCIgS1S7Gl0iOF0pA22KyF+EUhYmooNK00ozJM3r+gaPIIqETTrGsquAkdq'
    b'EDYFdgQ1QhD/c8quiclADMKdNS+dfk0d/pbAmIAsTkA86KO8qOVVRcEnavrVNaWY+7HBMCHr'
    b'9dM3U/xw8s9JN0dr114KcjJRIDucwON0LvabwDB0criegIMJDTOF99BaAvAt70YpE8X0mIOP'
    b'toX9Z2+cF3Pj18gYt34ViID7DExNjsIMtePHxCU4FQOFDzkMFLsxOjSe/6NA18lhWVevgK6L'
    b'79mHaIisR7U0jUpRRaVs44J5kRoKKfisaq4IwgLzd8t4F0/Ab1lYszWElvBa5B6lkHnxOclV'
    b'5d/7134si1Whw2huC4BzH8aHk+h/Gca2o08Ossbo5XvMaNpu04bUe+CN1YZa2/3UxnPYtKcL'
    b'r64k0P9lF27mV9+HFez0LrCOsGwxBUMndp+JBKY6vYfQd8c4dO1q8hmFv7UO3n3LgoO3F3g0'
    b'HEXoeOPfh7xslCVXKXQcSe2kVObAqZMzcWcL/KRvqaeDEJ4v8VOAAQAI1MRifLBK3QAAAABJ'
    b'RU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

application_put = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAixJREFUeNqUUktoE1EUPe8z895MY2tqkApqta0pguAP3ChV'
    b'gi0oVEHduLAbN7W7oCCiqKggiL+l6E6sgqCL6MpYIeJCXUsKXQTbhYKhNVajtJPMeN8kk3Qh'
    b'tn1wuO93zv0y5/zLTKuSg0EQYDmLMYbZucoLacjXDu1C1ffBl0j2CYJzXMh8HJQVIq7SEmde'
    b'TUGSAluEbOKskMLNgfUwXBIIENcWehMxCGZCW0SAFKoEwzFc6ZHavk5N6MRyl+FKv1688fE8'
    b'hcfC4tTLRBFJWFJDMkX3nLz75HUOXvU3kr2bYLgyUnO0g4A1y8hpr2QMd3PHMDbxJkzN+Eol'
    b'U0j3PW38awjoUIDVfZN3bqFFxUPyveND+PXnK2LOGgw/eYjLB9sb/ySCSMCm9rDapbDhWC4o'
    b'+rAzpflJFKZz6Fq9Nzw7bTVHQlB60fhopcPqcibg2ApbLzG4NsLOzHqTYHbNCvq7+yoDdR6u'
    b'lW3OjtYKStlQZE1iqW3A/eE0Th4AZrzPgFWz5vzg1Gns3w608jw4j4rOBaSUdFE7fism8Oj9'
    b'HXR3HIFP3iN0dxzF6IdbKBbX4ae/GdwS/x7g0ZEiNron8Dr/HGsTO6Bci+xOjOWfoTy9AbeH'
    b'pqilNphOP87ZK1b2eVWf+tpsoRCKbBw91lkc3pPFlmQ7Pk3MIPNuAIXqDcq9hHLpy1uTQA+h'
    b'7X8T138R12UL+itlZLNXcG7B0w+2xKntIsQJ3wmFhQ9/BRgAwTqsFR2Vlj8AAAAASUVORK5C'
    b'YII=')

#-----------------------------------------------------------------------------------------------------

application_get = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAiNJREFUeNqUUk1IVFEYPfe+O/PuPCefk0GLIFtMuW1VtOiP'
    b'UILQInARRUUbC4oWRQsJJ6MGAmE2QrgJN61qo2KKjVazCBJJIlCmRUTkokULsVKb99O5b3xp'
    b'RakXDt+73HfOPfd8n3A7hwa0slrCMMRGlhACi54/qAz5Tuse+EEAuU5yQFhS4ubARIvySKzX'
    b'CtdHP0JRQaxBNj49KnQ3b4fhUiBERifQuCUNSxhrawhQwScMx3BVhWqHGjTRgI0uw1XBcngz'
    b'M9O0J6Jw/oiLzhJIKBtSKGblwfcXsLMxCxqAin9L6RRCIf9K2pJJaFWL7mfHMVouomnXEdw4'
    b'3L8sLVaC1xTQWv9CSjtIO7XIbNqKwos2+JUiRq4+Zh1DodQWcSTFJcJYIAnbjmHDcRy46Trc'
    b'e3oCS94TXGzqwfPpK7jU3IMf3jDuF89QIAMVj4+2dZRu1bpF2zZu9bdiwR/EuYMdGCtfjs5M'
    b'Pcv9o4k8ssnPKxlobUdtqVpTBDBP8ql9pzH5KQ+6jVpoMp6czePk3vNwdB9nJw5dWtEgrV7j'
    b'b4FX5YcRqXChHVOzvdi9rR3XHvSyK310SVrC+vcAv7kb4mWOw0KBefkOsqZaDWW8g2eLr/mE'
    b'73MlNzd8oOIHCMLfWyjZf8jN2J8Cluz3SLrV6vDmuq4phF/LJfOALOH+b+KOdqJL1OCYucA8'
    b'OfyGoZHbyPFoTqxzancQ9av2X4gP5uOnAAMA9ZixG4ZCuckAAAAASUVORK5CYII=')


#-----------------------------------------------------------------------------------------------------

brain_trainer = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAApZJREFUeNp0U1tIVFEUXefOmXGcUccZn4iPMbHyUWYiFlKp'
    b'CX0EQRBBUJg9fvwJguonP5KgD01Io5/6SMqPCCIhIqiPyqSHD9IMxTA1ynR8zNg0M97n6dzR'
    b'K+pMCzb33Mtea++z97qEMQYdhBAYuFlX1GSJtV1Kyd1mZRqDIAiYGvywTC0xLRfvDzfqOQYv'
    b'fDBebp0rddxuqJAG33WwFYRYUPwWfuoY6ulgLacKfq/nUayDJIn36q61m802O4Y6T2Dyy0C4'
    b'OtNUxBUfQfXJy4AqpbfStus8/arOEdYLOJLTjqVk5ON58wXMfv+KnGw7FBoHmyMezoUXeNZ8'
    b'Gjv21UAS5XqDs0EgweXCzFg3MmJnIasU0wsUKU4TP5vxadyGJG2cZ2lwFxZlRBWQY51t6Vuy'
    b'QJJ3wuxIg6bIPF+FhTIUZmuY8/F0zQemymucDTP40fu23jNShv3H60AoRU/XU0x9fo+sNAGB'
    b'gIy4rdVAyMsnqEUKtJ7d1bT3YGV8amoC5MB8eK2Vhw7ArPiwGKQoripBZm4WIHqx5PUi8goa'
    b'GneXF4CJfjDJD3X5D+S/iyivrYHAZPgXPNBCPqhL85jzeEcjBPonfA1PHnSByH4QLoLlpTBB'
    b'8c+jprYU+W4Xb9+HmYkJBETtZcQVOl9PPixxJ94Z7h5A4fZM3hHT3QIGAmZUowIX+AlrDBWj'
    b'DZGXFTw5LkuqEPRCCAvo82JQNLYiwk1lVSUIJlNi1C2Iitrz6NXo0QQbxdi0/5esME95nrP0'
    b'cEkS9wKDJhC4bSrMlFYYHLLpZ8rhkWzo6da4caas/8oeu50Y06IEd/tCON/+kUR0wDG1Gmuw'
    b'Etb7eCRUpa6u3sSF/EH1zf86iIY8Hombvvk4T/c1/gkwABOTKeN1Na44AAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAllJREFUeNqMU0toU1EQPfd9k4qF+mkg0lREUWqEWtQuWqOl'
    b'2rpQ3HXjTl0IdlHowrVLF4ILCy7EjTs3KgrSoLaJdVGVCDVEix9sJNXGxmhsk5f3u9556bPR'
    b'CHZguMzMOefN3HmX4S9L9HSMccc9zTkP+DnGmMFk6cahp5nz9ViBAfODZG90wLGs8bbD/Wjt'
    b'2getpQVelQNmsYh86gU+TT6CrKqDsal0/A+B5MHoAJPk8ejZcwgEdZSnk7CzH2Dn56G0hqFE'
    b'tqGpOwajUkX6+jVw1xmMPUnHfwtMdO/ke0dGIS/kUH54D65jgcky/Ba440CSVTQdOQEntAUv'
    b'r1xG3/QsIwEp0bN7LHL0GNRCHuX4bRoYshaApGjCVe+kmPJUJxzhiUcfl1zXPRPq7ILx+D5k'
    b'VyhWDbDKMlh5adVFTHmqE47wxCMBRUjrSj4Hs1rBhgcz+J8Vj3eC8MTzOoDEwLPvIUkK1mKE'
    b'IzzxagJiNvbjO+TgujUJEI7wxPNG4IyZtmVpyvpmLJ/qB2ybFtzIJIKigHACD+J5AoumfSdf'
    b'WhpqC20G03Tv58A/+LRRRhsSIp8XvoJ4K2lEJnqjc/v3dCAQ0Ol2ayINDTAxvwTDqOL5qwz6'
    b'ptLtApeVRC07WSgNpzKzMEX7qq5D1TSoqgpFOJ1eLPJUJxzhibeyRuDi6+xNOu3UzNXtW9sR'
    b'DofEZQXBeK1HxzAwn/uCdx/nkPj2c9jH+yP41ix8x60Duy5sUpWT4iI0cB/BzEXLvjv07M0l'
    b'EbwVXmp4jXUWEb7RW/GqucILftv1z/mXAAMAUKIIFQm47kwAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

edit_button = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6RTUzOTM3N0U3NkFC'
    b'MTFFMkJEMUFDRjAzNEZEMkMwRTYiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RTUzOTM3'
    b'N0Y3NkFCMTFFMkJEMUFDRjAzNEZEMkMwRTYiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpFNTM5Mzc3Qzc2QUIxMUUyQkQxQUNGMDM0RkQyQzBFNiIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpFNTM5Mzc3RDc2QUIxMUUyQkQxQUNGMDM0RkQy'
    b'QzBFNiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PpLMCisAAAG5SURBVHjanFO7SgNRED37yOZFqnSCYiH4AQpiKxiV'
    b'GDC2gn6HJiYGLNL4EVqJKBGDQop8gVgI1kFIYZVCQwzJPq4ze3fNTcDnwOzlLnNmzpmZq60c'
    b'N3b7Q/fUcT0IgR9N0wDT0BG3jL1mIXOG5dKd+I8FOJguVWZr9egjvqoonRk6LjATB0KcHmI8'
    b'uvM/T3EGEFsko8Dqfg0nV4/QdRkf4nQtTCAkwAucAwyqmowR+KCOVNxC46E1YhYmgMJgrDJF'
    b'JC1grVBHzDJgE71mNY+BPS7R5FQOJIjd10xpE1R5o1RHNGJgaLu4reTQ7cseOAoFk09bkUDx'
    b'iBN4s0yV6TIg8M1RDq8Eth0JsiclOJ7UzA2yTCB7eE2n7oNrZQlm6n6ThYyHmmDoSerRCHB3'
    b'38b64hz6hLgs5fD2Pg5mH7pKD7SAAc85X6lhKp1CdmkeF8UtH8ya1Q31JXsjCZ8JZA8EXjpd'
    b'ZBam0RvIqpPrrQfxmjoFzsi0zovb/s9+QFmoAw9McLxQpmBS53hhEtaoGsuB+O4x8ajlCpm9'
    b'9lN5p4oK7/YvHqNf2KD9Zhxtin9Pk8/i7/ZMPet8CDAApqgNk/2TrwAAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

information = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAp5JREFUeNpkU01IVFEU/t6972fG1JHGrLBso2WRSAshonIj'
    b'FrZQ27QoEQza6K6gXYS0KKhWuijIjbZw0xhRoEagUhRWUIJSWuL4A44OzDjhjOO89zrnzjwZ'
    b'68Jh5pzvO+d857x7NfxzSq+Fem3b7XBd1+eSr7FpWkpKrW99oLUzn0schauzr22o0dC04ca6'
    b'cpyrKUMw4CMGJwPr8RQmpiIYmVzGtuteWOtvGdlVgJP3B6zhW1dqEEvZeDcTxczKH2xuOQj4'
    b'JY4dLER99V6U+CQeDk5hNb6linABwQV06tzdfgqf5hN4Nr6EudUkuluqsPS4Hjap+L2WRN/E'
    b'ssKZx3xPuc4zd1ysxNivOL6E4yj060hnHAiRnc5nSewxpfrPuGkKMP+JE+qlUKdwHOd6+YEA'
    b'vi4kiGjAZ+jK7r2ex8k7H+E3dVjk8y/jzGM+52XVQ7PC8TT8hlBdaSxkSPf3u6dV17P3P8OU'
    b'WhYj33BcMJ/zGBe85XgqA8vSYRoSBhtJHpyMqAJCl9BzccaZx3wt9/1YAQVski1Ud2pAi3Oh'
    b'S7VfmLpQJnM7yTa0WYFXwE07tmNaNB/NlS1AoJdg5jp7vhACmQwpoDzlO6no0MpKDAW0bR+T'
    b'VUdtRyLPSLdQxRlnHvM5D7mbWlF69cVCU8MJFBVZ2KZP2FQdQHNtcOfKtg/MqmSDiiQSW3jz'
    b'dhrrzy8foYsU1gkPZxbfd42OyZ5LDcdRTEVG5xJ4NR1Tl4iao9hv0BgCG5Q8OvYDzOc8TwGf'
    b'4pLzN9vkoTM9dbWHcbSyDEUFJrzHlNhM4+dcBJPfFmEvfeiKjT/qp/DGrsfERciqgq1Pb2v+'
    b'YDMt0/QA2l/aTUZfRkM3HpA7y8n/vca8U0HGCxB5MYcs6snOf85/BRgAU2QTxLlxCL0AAAAA'
    b'SUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAk1JREFUeNqUU11IU2EYfr7zMzZHpbC1jChW3hRZMfuRCq+S'
    b'TLEbu+pSCsIgL6RdWNhl1E1EQWk/4GXdBBGxfggbyFaa1bQkmS5jbLNtba7trJ2/r+8sFzp1'
    b'0cM55z283/c8PN/7nEMopTBACEHw7tGDuq4OU00FFvog7OI4EF5klUddp4cY7RJPwCLk8vn2'
    b'ja5dsO07C12VAE0CJ66DWsgi9KAXT0di51CGJQIC0dvM9i2Q05+Qn70BcCZYt7mRePsYUkGZ'
    b'6u4fH6woIJpovdnmhJz6zCyvgVizn5lIIxMcRUvf2Am2JVMuwJVegneaXFW2mqImVcLMuhXi'
    b'2h1IjnkQmM1ejaUKE1gBfx1Iv5SOaocTVE4AegFEqELcN4Cf03Hs3mx2T9064DaGSHihONQ/'
    b'410kwM7fbnFsgK4lwQmWYm/94R44migoVBCaY5VDxNOPuWh2aGu5A1FEvdleCzX7DbzJChYn'
    b'lMQTI19wPF+MLeb7gFg097yxZ6SLdpcJEI4g+uIhc6CBqjI2He+DMu8FRxUokoT4aACTwR8D'
    b'xy4FrrDtM8tmUHfav9eo1045GzuanTcJOybPc1CyKqJeH7wT6d7O61+MGCOrxfjOeLS4qi+b'
    b'7XY2oQS0vIzI6yEMT85fZOTbbDlV8TsoNgQ0W2p3Qkl9RfjVM5y/F2p95Eu+WYm8TGDmfsNJ'
    b'qlFGDiPuf48Lg6E2Rn7JlhSsgiUCskq7TDwwF/B/337mYytrjVciLxMwCTik6TTDyEcWyP+G'
    b'kW/p12RoYPee/+H9FmAA+Yf39yJOQikAAAAASUVORK5CYII=')


#-----------------------------------------------------------------------------------------------------

separator = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6Q0ExQUNGRUY1OUI1'
    b'MTFFMjkzOTlFMzVFOURFNDVCMTgiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6Q0ExQUNG'
    b'RjA1OUI1MTFFMjkzOTlFMzVFOURFNDVCMTgiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpDQTFBQ0ZFRDU5QjUxMUUyOTM5OUUzNUU5REU0NUIxOCIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpDQTFBQ0ZFRTU5QjUxMUUyOTM5OUUzNUU5REU0'
    b'NUIxOCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PrqlUgUAAAAtSURBVHjaYvz//z8DJYCJgUIwagAVDGBpnLCIonhk'
    b'BGJjigwYTUjDwQCAAAMANs0I/5zY9nkAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

table_import = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAfhJREFUeNqkUz1MFEEUfjO7i3eQHGpnhZW5iCEk0NmYIIkS'
    b'giYUGi2vR3qFy0EQEwoSKiVQWiGGggvFXWFjZw+ViUZjjMHjctwhs7P7+GZm71ilkbDJy3z7'
    b'5v19b94TzEwX+fzrr6oWmDBhFG81VfQgjIliKETnRiTmDgv8BpKop8s78NuRYngY53rp/n9n'
    b'7y3uXO4EMLFVlND5OIpEASSmYm2NSlcLVl38vU6lKwWTjeh2hUIk9dvOGiWAgjWcP1glFpIk'
    b'Ss3KkBZqb6ze4HlgYzeXOPoaUWI0sqUi0ovjJKY26cfyJIxc4I3qHj25m7cBDH48krd3zp9J'
    b'7jcV77cUN1qKvh5DuTJJ155tUK4LTQKLADVe8pz4yZnxTvsgOPWOX1qu4X1ZHNPvaX3iFmnc'
    b'6oSaBCeDjUyP9VP2RZnou2L+Bvl8xPxLObFBpzYZ1Hi1usuHOI28ruxyA2ctcjaZ59vs35gr'
    b'2yc8Upp46aErC30wVOygQDJJhYFwWMsUBciQAbnZ8qd6acw6v3s0QH907IYJZZsEaQoRnrEw'
    b'ctNSEH2LFdvtYx2hmSGFL8f/Gpa3H/bo6Z38GWy+bgSQ7TJ+ztwb7g68M9OWdkhjS8mTroLO'
    b'LoS63tScM4PS2QWRXKaw3QU49/iiIf5JOAjxzrGMkbjoOp8IMAChbgwty8w4LQAAAABJRU5E'
    b'rkJggg==')

#-----------------------------------------------------------------------------------------------------

table_lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAntJREFUeNqcU0tIVFEY/s65dx45vmYzMdjTRUSiSREtamPp'
    b'zCAU0cYekAWRm5bSQjQtXEatoiwQSpoiGoIeSjVaWU4JLcIeDlbKOOZkhTNM4+TMvXNP59x7'
    b'nR5ESD/8nI///v93vu/cc4i78158LpsrVTRAYwCBCA5M9CcmhMBCAYdVSsRavU4UH+9l/xNi'
    b'TlBSRWMG+dM6IFQPPPOhvXcKeO7V8zd8dxIYqtHbs5oxJsOcb5vtApUkyFyenSrojHfpdR0n'
    b'Lug2rBJDR6IbHYKASQYBMxn215aDcqsWXg8Ew9hbu1av3+gfwx7PGmic+Howhn1et17XWJGp'
    b'wAw7bxAEQoFMGWzUqEsSP7T4DFT/LjQQC7RRYJwrja62g3XvZHmCQPANJM4gSZRLpQj0hw3Z'
    b'FjuGBwewqYSizLeb66V8IxkTN+8gNPqlNU/Q6Kvgv4jvzi34H4RxwGtYuPIois2uJOQlyyA7'
    b'65Eea0ZqUkVUceLg6b5zdIFASNZT+CLGqmNKoXx6BceKDcjGeqBmCpCMZNCZqhdjs3kFV7kF'
    b'cUlkbsPGD8I/wC0QbsdWjPnxx3DUNEKdSyCTsiDzXcH5wovQzm5n+d942FOhr0LSpYdhHNpm'
    b'WLg8NA1VTeP9rduwlTqxfEslXFXl+Bx6jXcjH4OUmLeUmqljxhaEgarzqGz5gKJ1TShZWcZ7'
    b'LIgE7qN9pApbW4abFn2VJ67tYCx5hk33eBiLDTLriZC+C3Gf7EvOqaxIyWk/HxMx3pDGQZbY'
    b'ccTai+alT5BmBWj4ehRTzIVCkvk201ZXLFqrxX3BPyJyatWLuFYwW33sreeXco7nSywyNvJc'
    b'/7cPPwQYAOJyPDBxd4URAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

table_refresh = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAqBJREFUeNqUk1tIVFEUhr+zzxnH8TZjQSKBVNRDiiFoEYZJ'
    b'NIYlUZAvJthD0kP20OUpyvuUSGJCF0wsYeglJNLITDPELhamWYQEUVSYVGBp6jhNczntMzNp'
    b'V6jF2Zx19lnrX/9e+19KoqNrwvXVb/MGIKCDgmHSCXtzfvBRgrsmAVERYtKkinjNSP5cuZn/'
    b'NVtFly1W6Gheo6xhd3NAmGSZAOWTzVTGF8tNQeXEecoX7JGuhazOVtxeGKzWJS8zui4BCOeX'
    b'fjqHUNUgPYsIUDvlRBWRWM0aJ2evIBQNv6LQsvs02dXGeZ7ix4emhxEK7ctQ5b5Jg/beMTLT'
    b'vBxsTJAgMlYJdcKeCkPv9lGzs4yq1lSizEgGYYuUgUIGmlVwe57J5By2rIcliaFkyRafP7Se'
    b'u6s4kF/EqXanPgdwuWdEVlOxRFjpGM7BngXTHjh7ab5x2Wth+VJIiltDbYuT7sNkzAHsyk0J'
    b'MoiWDC72w+h7iAlksd/eyY7M6GBMZoVCenIU1U0DDPg/sL0+YUh8BzCLEP0vfh2PpNlcoNNQ'
    b'eJsT3TFkVYU0YfSj/sIsvaU6iVod49PoSuSRa7rbkUdT94hkIIgwWYg2x2NSrTg6FNpKzpDf'
    b'WMIh+8zcUR69zWPa1cfwKPPXWLwpJfg2KLU/cHHsuoJz71FuvChh4ypo6ImZ74X8XhxLCEAJ'
    b'K1b8oLKyqzGUF2yjf9yBLgNX2GBlcuiWjPjRMVmkD+6USSGZVPGbTJ8c19kgxVKUtxqT9SGv'
    b'XsPNez/HvNHaJJiSoSRWdU65fHqs1x8IDpPRB021IMQi1llSyM1eSFffR+57XkqVzsgkn0z3'
    b'IQK+adSIOOMAaUaD/zY0W+sYnHDJUSkn45df/qSaW4//ZfDSw+uP9k2AAQBNZtnn2K837QAA'
    b'AABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

table_relationship = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAoRJREFUeNqUU01LVFEYfs69586d22gTEgXuCsGCoEKpsPyI'
    b'DGa0RUYhBNFPsDY1pqXCGBUEBlKUG1tEBC4blckSJDVEJSQZDSNxEVRoDeTXfL2959yZFqOb'
    b'Hjicmfc87/dzhd3STwIKBCEELAPwecwxyzROunZgMVSL4s7o3GoiXZrMMJNcPiAgN8JB5MPf'
    b'NlCx0xYwDfHPtppEabxjK9fA+DlgPIC2yBIwelobdRaOTvxMMLUtRYWux8RlPpfQMfAd+BCA'
    b'bF95zJkIHiOF9l89aIdbIkEiTTuQgaX9qn0VqOzk4Py2b08QZfslwswXn9eIJCfpG5pDw5kD'
    b'KLEBp3UQfqdI1BQcRyINrKdADxsfYWahCaqr7nGg8cRP1FfthvTy0Ew+0shA/VbIEGdHATaz'
    b'zm3nm/FqogmcQwc4e/QCTJEAjwmiKzJLBkcweAPJdAbXggdhtYyivuiU4AB0ve4qJr48R3QG'
    b'GLlNePp2hbmbnGQDydQmsJwiihPRk+g8/SYXCH2kwD1Q33Qt3X0NqrsPEs2T+m05nePHNN+w'
    b'uWwvl+1IH/zZ1VQ6R3CxugTzP4YwFgP6b6LcEnH95uGy1VhNvm2lhJ43MfJahRiev4LYt2Go'
    b'zTfUONz/Osam2fkGyjnRlLd1kDbCATyLzkJyy+qkuWXuxcWxO6AXX0EvF0HhYS77gZZa2d7O'
    b'GFRX9q2I5uX4ve9i+pY5rR0qrkJ37wg8UknZLbuxC1Pv1/64ihNav8jxDcr+10PLw66OSTiW'
    b'IUyRYsd1LIWqlbxpOylLb0tEf0Tq8DJh8XQckVmyhM02V9AKPok4B/GrVRNlSyH3KsNW8ILx'
    b'Kc92WCXMJ4ptOvgv/BVgAO5JKpHTWRGVAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

table_row_delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAkZJREFUeNqkU99LFFEU/u6dOzOru07gWuBLD8UKRhBhCanR'
    b'Q2w/CaQnISj/gP4DyV1pqaDSCiIM3Uef7KVIkfKhH7a1LSYRBYkZIlQkybbtuts4czt3Zn9I'
    b'b9YHh/nmu+ece+6557LmxNRM/rfTYbuAKwEGBSJl9jdnjEHnQNDQ5nWNtwgVnB04js1iS2wy'
    b'YpkM3FbbKjyPAi9OAKljiE0sAy+PelbjpE8STx323FXFKlKgHH/hxzC4pkFQeQFuI7E67Ok+'
    b'vwtJa3pAR3xtDHHUTiVkOcOZ6A5wChYacG96Hj3RiKePP/qIniMtcEl/29uLbU/HgU+/IHUT'
    b'LvnzSiqjDiANQpASavASKeOhEHT6GuTTlHqAtlsjSLeGUay38NMM0RGYn2D27DmEU/fBNIH9'
    b'pC14TZdolw4yXaexeP4m2gwTpdsXsef6Hbzu60bAELUETRTcGU/A/v4Vnib9azO2NmMmEcOh'
    b'0RHMMQ7NakQpOYRd/Zfw5uplKVC7YehLi+CfF1BJqirQikUvl1n2M4INkK6D9fya30TlpJDt'
    b'PIXHySSY0ME482WV4Mkz5A52Y+xdHjsp0KgLorD3AD4MJdA1u7wPgb6HUmGdzCZzyUYz32QF'
    b'yfSXKp+ONMr84IB81RqWuJaRwcE01F5eBZpXjn8nem61OnEin63yQsdJpG9cQfv7FQQKWVil'
    b'HJjVPyH/aZTjU7BMzkQ9d5Zorrfbjlt7TKz8hjZMnEeouaq/OtUd1JDj6p9Wdm9o8mbgkM0x'
    b'KSX+B38EGAC2m+wilWllXQAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

table_row_insert = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAhtJREFUeNqkU01oE0EU/mZ/0nSjpqJgCQiCRSkePGjpqWKg'
    b'pRYqHkUwQsFb9SgIapMahUKPRTyoh4BC9SA9mFjFFukiFq1XsfUHrSK2NJRWIpLN7HPm7SZp'
    b'vFnfMjPfvN33zffevBVEhMT1p+9KZbnf8wGfAAFtCoTobyyEgG0AsYj5Hppg21CBNmM6ztCc'
    b'+mS2F33Ay+PAbB/ShW9q7eXRgPOL6rskgjilRiuIXZmkUvYYhvOfIAwtr1kp/Q1JAa8pSOEg'
    b'BQEfnvSR6W+Dc7kAVmAaUX75+PVezC8ewkBvK5ogkerewyNCdcz+nrZaPZjAtoCj1wTuDNzA'
    b'56VVxJSv2Xaw1QYPJ7K9ju04tthhvNJj6aXDTmL01BjefBmEygATrsSrDynk3Cn+TPtybjVE'
    b'lWC+C/cGZ9RGEfSPCsqezGDu+3kYTUqUyjvVZeLm9BRyZy9i7ddXTRGe6CPu7MaZWyMhmQFL'
    b'kaBUKYKiG646tI/0EEuVhQbfLtrXsLceXcBhKcfmzp04jaJ5l50Tsz4OJLoxfPsZc+pDiKpl'
    b'W0B765EQ++BG2nn1OSWzoPtve6gzDW6ScfdHrWEeuKs1PD6zUsPRS3niIpYlMJ0hdAwJtCda'
    b'mF1661ow43J5Wc2B3/OKat4R1oACBfH05KZbmRU4pr/WknkSr0idl3rI5xWE+t1twHprmwZi'
    b'lvhZrftBXVD8u0n+F/7H/ggwAEYOV/C7+oSSAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

update = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAtBJREFUeNp8k21IU1EYx//nbnfTzU0z05aucgMDCc2KhAiE'
    b'4VwUgRRG36IP9aEIDIOkYWA6JAqiD0F9KJJAAulrbXNZoGFi9g4VimZrvrR82ft27+69nXt1'
    b'NkM83Hs49zzP+d3zf16IJEkghGCjUe/ySqyKIMkJPpWKtPqcjtGMjcgAR5ePF0VRLYgS6AOG'
    b'8tQqBn3OBoVs6/BIl4/XYHI2hJefA1iIpHr72xwnZRsjT96r9tqK0oLwhWNVaKGOLSf2Ii2K'
    b'qzeQgQ+H/PidlHDGXglLiaHJ1um5uwqg411gIWr0fQ2iyz2Gtz8WAemfBIYSQqEYXk8sont4'
    b'Gg37y2HQqs/Xuzw7FACltddWmJCCCjotC3OhXjmUGd+f3W9Mzkz2MNEIopyAgYkQ6qrKIKTF'
    b'm8s3EMUreUY95qI8WC6JHt/HMSYrsFODT90Dt063xoP+HsJx+BnmodXpaARJ0zKAEG2II8hh'
    b'NfTqIkbuNZ+i51NZiZDX/vePrzlFLoUcrQZhgQGhOhWA/K+lpIC8XA34RBLhwNiHV66mQ9mp'
    b'dHT1qWJB/1QqHkceBSzRgJJMEOXFnyRQnK9FWUk+zbtHxcVCo9kAmu6wrcOdY95SoPhFeAJZ'
    b'5YoEeSEiwgFbC40QBPEG1uQBoDWi21ZkCFlLN2E+AfA8T6HgFAAfW/ImYzEQRg1ruQkFhtxL'
    b'tuvu23aX15oB0EJDo20PazaboNGokYhGEZ//9UgBBEaed85Pz4JlVfBHgaN11aiuNDfTQ+NZ'
    b'GvApKMAfA002EJyZxdCds+0KYNzXPZxYnOud/PINsbSEQILB7l1WWfeaYgKrRYrRwFykh8W0'
    b'OUy3p0lWM22va33yQF9YXF9m2YktpmK86R/Ei7bDitHu8kiyDEluFurPMIwMTZP/utFSceTc'
    b'QVON/SKbazgg7/c5HRnjvnUaVSLrtDMtMZTS17jyPbpRq/8VYABm7ivbCz/37QAAAABJRU5E'
    b'rkJggg==')

#-----------------------------------------------------------------------------------------------------

watch_window = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6RDQ2OENGNTYxMDdD'
    b'MTFFM0FGOUJCRTk2Mzc1ODMxMjgiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RDQ2OENG'
    b'NTcxMDdDMTFFM0FGOUJCRTk2Mzc1ODMxMjgiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpENDY4Q0Y1NDEwN0MxMUUzQUY5QkJFOTYzNzU4MzEyOCIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpENDY4Q0Y1NTEwN0MxMUUzQUY5QkJFOTYzNzU4'
    b'MzEyOCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PnZsAM4AAAKZSURBVHjajFNbS1RRFP72OfuMMzqOTk5EIDqZQ0Ez'
    b'yNB46SXEsNGgMYp66WdUEoOUhZaO4m+IHnqT8PLSdJGgZtIoG80KHEMjKMHRYCTyXFv7xDEf'
    b'urhhs1l7rfWd7/vWPqy6P72hGWalZVnYzWKMQZGlb7LE/CLmorkv0QTDNCH9p9mkLUsSesZn'
    b'KiUmExgB6NRY5ea4nP4ETgjsL82Cn04IwydrIHpckAUfAWDB71ZwKOCFzGCj7iC8DSgADFHr'
    b'cdlABmVMxkkCBa21btq12O1SqUchBsniOLjjXX5xEZBkmKYBYShjEj4uLaKwtmazEHeBQADx'
    b'zlPQyS2Vvv6DKZAc71/OTCM1OACfrwIry8soKyvDemEdsaYWRBubcZTOQqFg1wqAZPE+NCZb'
    b'28Z3nTkLhXN4vV7EGpvg8ZTauhVFgYu24nL9NpTY6STBFCY6l5MTY6RARm72NbZUFeEjEQSD'
    b'QWQzz7cbReyYa9rCdgDEOzrwLJNFsK4OmqZi8/sm6utDCEciqPD5sEZeGLpu11ZbGzaAYMid'
    b'sT1MPwAnBiNDKSrUYJJpnCtobWtDItGFifExzM/NwdJVXHQp0FxuizETXJF+IZyOt2M6m0Wk'
    b'/QL2hxrsyX/+MIvixhLu3b2DEi4jcuIcqg9HIZEHX/JzeP+UZJdyViy/kUZ4ZAol9LiCkUZE'
    b'D3ixz+/BwYYWLORySC5X4W3uDeoojgbLsddfgtpwjEZOz//rtc7jm73xWP7m+ZimG5mFJ6NY'
    b'JXFyBcfC1Cg0Xc+sXE/ExPmO4lWh28cx/3gUqqq9YjW3H2GLHsWl4iS6+4dDV7uvvLBMc4/t'
    b'tSStD6SGmnt7kvnevlv1lJt2cqDcYGro2J/+HWGAMx1he+5fuZ8CDAD/Sv46ZbrYXQAAAABJ'
    b'RU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

image = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAexJREFUeNqUU8tuEzEUPfY4nsyrSQNqWfR/WNEdK/b0D2CN'
    b'1C76CZQlYsOeil/gD9i0QuIhhRaFJnSSTmZsju28JkIIrnRsj33vuefeqxGPT9+/rBrztDYA'
    b'BNpmV0vrTklAq+js7bOHRzg8Obe31tpr4uoP+L4F5+f8D0/ecbVQNRlTEs9ESC/SDCIjdgrI'
    b'NPe7yLgXub9XWkO/OoNXTFN2obtx6noDyN1diB6d+wVQZEBCsm7qgZhw8jcKU25Zld+n44Oc'
    b'JEUgcUoS3mkGdlxwTKmVT4ZNAscmuhJiL4XcS0iQUDqRJiGz4t5J4HPbptVW5cKdAnmfDgMS'
    b'DOjs9l7oBWIq0jk9iUayArNNEOSLgSOIIe4xmBAsA9UNzPUFmkmJ5uIS5scd5OUIxfMXDBBr'
    b'Ak/iJPe6zEzJegpz9ZHEVXiMDOT+Dp1mED8ny4gFAfVE7jPXRApbfqXUG6pgw9wY55Q8qmFM'
    b'BVHOeae8/3IO6xK6Gmb0mSSU2aeaImI5ESwT2hmH3SEkg6QJue1GE/0ov32CmfH9gI27nQIl'
    b'FcQdnmvgVwUzvoMdT/0ZLQU2HLIPJUzraW1RGKA3ufonFgRKbnXzH20VNx8P3zw6Pn/SGLMk'
    b'/au56UVSop4MXy/7d0Ds4/9tyL/xy28BBgAMXMtNyzRrZwAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------


folders = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAA2NJREFUeNrEVztvE0EQnt3bteMYiSBFoiOCBhqgSBpeVUqQ'
    b'gIYKgaCBIkhU8BegJBQGIagiAT2BDhDIoolIHIGCEA+FFCgmjiAJ+HyvZfbB2efn3cnIK63s'
    b'27ub+Wbmm2/3iBACBjkoDHgQnLxUmPwhfGe7CAK8FJHbhFLwgT0Zn3pxGhe8fgNgOPPS+cHL'
    b'D9A82hckCo9ZUCpcOIH/cjg3/weAjIrcc8H5cAPjt4xnOXzIjp0Dr2bD21uHNgghDciaUimX'
    b'qAW+sGYxW6fiZouF/wIXBM2iJa6tyUoIHwJ7DcanHmqflOh7lEB7BBwWC2ePJ8lWHYCwMQCu'
    b'lwjVXBAY0fornC+Vf7m8vPAJ1lfKbQFQxoFlhuXVUEIAMmIPKEcAlDelWIQBfp1bgpF9Z2DP'
    b'yaO4LEzUDc/h+6W7F9vXqCsAaYi4sLLwGdaWy02dYMwjOXcdGIORUSxupYhZeRPxQ7Dkmb3X'
    b'QHdSMhIaRXDR+XeYuPoY+eBHu0EXAPzyUwTiQrDxDggblk1qYhcKAAS1VF1gSuDqyH0HvC/T'
    b'uhsaUkyQANRiShdoLq/fIWF6JDwMwlP302VAdQ1aDP4g93KGjA0AUA+Wns9B9eeGrn+0QOrV'
    b'nft9BMBSAiAGgKiiM0nEuh7I/qecovNfMHFlxpToX2m0c7AsmC+cByszlLIE4IYZoNgJQm0T'
    b'dQAERUZF7qNgfbzZVrAC11FX89OHV+MKVlMJZEBIJIuHxAvfwvqrzAuni2A9SixYDQB849AG'
    b'IgGIRgJKY+ZRZHo/BateAouY3bmmOECaUXNm1vorWAoAkaliLiLDumblSr5112YUM0OVXvRT'
    b'sCQAUdnyiot3Zo6wbBZK9+5DEIjWc4GqAlOK2VOwVmfRgYOC9R5B5+qaIbMhpGDZkS6wJ6+/'
    b'voS/o1FdaBl8/vaxZ5qsnQXLsFCD5kOtZRI0opjSYRXnN5zlHpvIDn27u2BFgUCrYCmtscP7'
    b'zFjcjH3a6SJYvUd7AAmPkJ0FKw4AosrghAxjibevboIVK4ZAERnSA+gsWLH8Exm7kxZAD8GK'
    b'/TXihmeJRAB6C1bMkbHCc0MiAILQLRSsbZ0FK14WKQZS+e0XIWEBR3Du1nqQLvNNTF6T+pPE'
    b'EDc5z/Thg0goFmsRHPDH6aA/z/8KMAAV2HjZKbRagAAAAABJRU5ErkJggg==')


#-----------------------------------------------------------------------------------------------------

setting_tools = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAACK1JREFUeNqsVwtQVOcVPnvv7rIg4b0IiCCIyvKoCtSmUbFq'
    b'rXHU6sZHaMdBbWo6mWkTjaEq+EzAIRaTMSapnThl8rBRUTCdxrRNwmNRpKCTovJeQYF9L7vs'
    b'7t33q+e/uZusiMi0vTNndvfe//7fd17f+ZcHU7y2bd8RmZiQeEIkEhUnJCSIkmckwbRp04Cm'
    b'aZDfuwc9Pb2yk394cyUu9R19vWIvRVG7vV5vklgsBo1GAzwePvB6a+0OxwFc14/r/GRf3hSw'
    b'6QNlh/4oEAh2STdugPm5OcCjKFAoldDa+i/8VEFfX1/je6dP7cC1hvLjb/YlJSQmLFu+FMRx'
    b'ceD3+xGcB06nE/r778HX9Q2gUAxnnnn/vT5Cgv8k8H0Hymry8/IQez0LbGWsUN/YBLLmZujq'
    b'7KxkGMtws6ypBde636io7Js3d25CYeES6Lh9F65fbwWMBGvx0+MhNzsLkpOT4IOzf+7B9SI0'
    b'52QE6P2lB2vyC/Kkm6QbYXTUAAajERoQvLe3V/9W1YktuEaHZkZj9pbsf35GYhKCL0aCMvB6'
    b'PIBRA7PZTDyGru4uaKivZ4NO0xTZP2wyAiTs6Hk+gm+AB0MjYLVZoalJBnK5XIHgW3HNEAk5'
    b'mgtNGBERcZSEveN2JwtOUTRbHyaTCV4/emQNiVDQ/sbAF2pi8MM1PywokG56bgPcfzCEm4wB'
    b'hXmMjY0BxmL5hgPXoNnQPGghmOvp8XFiUKvVbM4pigd8Pp8tPrwG0e4EGfltJQ/GR4B/8PCx'
    b'2vy8hetJzgcG72MIGXC5nODxemHr5k1AU9S6iMhIqDpRKQ16T0CKzWyxAEEkBIj3QqEg2GPt'
    b'RKEeH4FQHo/iwAcR3ITV6wCnwwl6/SgW3nXY9JyUbL6OrA1+kRDg03y2rb4F57M18KRGo8YV'
    b'XXV+3gJQqtQwNmYGu8MFDocD7IQEtpFGq4Ov6htZMK6Kv7u8HpdqcHAA4rHvBQI+kkDj0+D3'
    b'+SYlQOjxy49XXhGL49empsyEjNnpbN7Dw8MR2AkuNAcSIWlAYYGBgUHAZINSoag7dKiMdIIX'
    b'LXb3nr11RUVFS6Ojo6FfLmfzLwoJATWKUHt7O9uKLCBbHxRUHi8PIQXM58K+9sVf72QX1Dc0'
    b'wSCGnxRP6qw0BHaBx+1inw0NDYNIJGTTMGbQSZ+ifed3lx7a9kbpgTOr1q5fOm9uBvwb+59E'
    b'CBWTJZGeng5ZEgn7WyCgQaVUw+W6ugGuDVkCQovF1FRzqXaZBBeGhorYwFgsDPZ7H+h0GvY3'
    b'2TQyIgIWzJ8Pt9rbICsnGz4OX7Y55sjnUs8coPN/kAVtHZ1gt9vQ7Kz3MVFR7HtsgaIedPf0'
    b'QHd3N+rB13uDU/AUWtrekn2nM+dJCmfPSQc3ei2XD0BvT3d9W1vrJQFfwMMo+NNSZm7ZuGHD'
    b'8qi46fDqN27Ys3YltKkYaB9SQYpbBa9m+GBIo4fm6y2KyMjIGKyU0GlhYeiMhQXDom754E9n'
    b'9uHXB1wbu3hcK0ahpSCJt2fPzihMTk6Gjo4OOFS2/2m8r+dEhJR0zNbNm4/1Ltq15rfPLoO7'
    b'OjuoGQe4/RTcvDcI62g5+O42as+cPftLrjYoHFzhqA1WTi9MHHBAwPw0mV5EEsmNGy3XWyVZ'
    b'ObkYrpmMxdRy7VpzNd5XBeQ2dEVxjHXFS1UlaxbDba0dVBY7uH1+8KBFhEeBbNgAjW+X/AzX'
    b'3kdTEvIMwyg5DdBw0m0KVsXgJiVkotGS0CI48SCKR+LHi3np3dnp2Xn9Fet/DFflRlBaHCyw'
    b'G/10+3mgwDkR5jXBJv2Xn+07fKQI33EEYfgfO3CCtYQLC8OBkzDZyf2Y37yThuDy8vXPsOAq'
    b'xo7gwIJ7EFyJ4F79AHy1LRskknmZs+LFmX+vb6idDHiiCEwoVLH7zhcvypxb/fLyhfDFOHAv'
    b'gqtxTngMD+BUngBong9+lL8Adv61D9r1PjCZzVd0x9Zt4fIPU5Hih57FlJzbvnx+TnXZswvh'
    b'ar+BzXkwuM5shGGtEiS3qv9p0KlBgAKz8cN2GKMi4C/bl8KyeWkb4w7WXRwX6cem4CHw6NfO'
    b'Fa9YOL9694psuHDXwFa71/89uN5sAKV6BIwflhXdbv7yaphQMOtvguw0QXwa/H5VDvxDboFf'
    b'LEgGtdUr0UlW5dpkFy5NlJKJUsCPLqu7+GJhgXRtbjJc7BxFcOcE4MNgvFD5vO1O002u4BLn'
    b'vnPj5ic7noa3GrVgRS2ZFRUGW7Nj4FRDJzR29dfpy6UB6X5sBOjo0tqaPasXS3+amQgXu0ZB'
    b'8zjwTyu22O42t+E76kCn8HJWFFzptaZ6qXAghx6H2wMjFg/8alEqaDAS2gkiQT/keWntJQJe'
    b'mBEPNei5xjoxuLOrpcJU/8nnHLiT0xK/raX2RmjukmwPX5gaIopk42t3TU4iQIAWl9We3fWT'
    b'RUUr0fNHwbEvGQsoVA/A2XntuP7T8o84gXIEeUNIuJkbn7WG5CyRuGlhqjD0ySQCBKbFrnnh'
    b'YunqBVhwweB+1nMGDyQjygFw3JFV6M8f/5gDt48rqu8UdTISLyAJrc0n0WevzrM2na8JtKFo'
    b'jjgKH+DOmPNvW+178Psj/eA2qGUIfo6TWCsHOP7yBhRUdXLnHkbRI9Nqh8GKwmtFJRg2OeBy'
    b'txFKVmXhHwIBe6oKEKDUFhtQOJYIOLFgcM+oSqaq2v4Kl/PHgU9KwoYkbEhCybjgldpbwGOM'
    b'TWTABVIQxiv4+ZasmXFRGjsfnLiFGY/hQ4p7qHKqZtXJHXtwzTA3lLxT+DflfyQd/JBUUVg0'
    b'shqCEXmnTFNV/DI+Hw3oACYKMhLKLtfyRGEpeKJmj05e7fAXqlO7DnJDyThFcJhgwKUkvvbR'
    b'aaE4+RmXbqRFVVX8O27PsQABMutj0WZwk5DiRqaRK7ixyfR8iiQCU9bM1RHrULASCrhzmpBT'
    b'SB/XZvb/wvNH1JU7xgs4x+z/g0P/3+s/AgwAdGqB/H5XELMAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

add_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODI4RUQzMzU3NkNC'
    b'MTFFMkE3QUQ5Q0UxRUYxQTkwNEEiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODI4RUQz'
    b'MzY3NkNCMTFFMkE3QUQ5Q0UxRUYxQTkwNEEiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4MjhFRDMzMzc2Q0IxMUUyQTdBRDlDRTFFRjFBOTA0QSIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4MjhFRDMzNDc2Q0IxMUUyQTdBRDlDRTFFRjFB'
    b'OTA0QSIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PqOUi98AAAIcSURBVHjajJJNSFRRFMd/9+PNmwwNxZBCbS0kuIgs'
    b'wSBoG7nRbbsg2pTYx6YWFSENQou2EW21oHaBqVFE2KKNUaJFHwyWFFI4zVjjvNs5T/u0yc7j'
    b'/967557/uef87zETF/aSJAkhqbwD0ySgugXFiLGuz1oroQav5Er5S+g8eIYPz26J0/6Dn9DY'
    b'dqB38trZQBRLHocNyfJw9+FBSvlxamo3sbG2rip0X+M0XnmEgJdX7/zzKZLQQlp+YB0LLEm8'
    b'8nTljfQSxVnmp25KS5b1NAjSRlN7D8pTM2Pnu0OlXJZfm/ZvTPUEQUpWHSDBRRHWeeODiNh1'
    b'6BKv7w0J31dNYL5fQrJM654BHl7pl3i5BS2pXFzApaevbcHIY8Uf4eSRfVvBl0rEiXgEIqIh'
    b'fP2E804yujUJlBSbmOHCOGNLMxjpwExcpau+mccNebRmQrmA99HqDJjfTs+YiOuLd5mumWF/'
    b'B+zaepzJtzmezOaJP3LZpgRN4KJV+B+IZJ11MaPFaba3QuEztDdcpFCAtpZUzyPpXZikiM8I'
    b'OXIC/xMZRyR+FW+nnHysc2VIjsp3x5aTOkcrc+BDCbLZvyivLWRQacZnc9x+muP0vsC5O4YN'
    b'kldHwUvY4qPR+7V6G38OoQ0ioOi/u6GZF3N5tjXCg1enxA8v56C0wA1VrCMVex3rGeJEXT19'
    b'WraOipJHBug3/L+JjGz+Zf1e8OabAAMA4Yi/RrV3XFkAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------


edit_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODlBN0YyMTE3NkNC'
    b'MTFFMjhFOEJDNDUxRkU5OTMzQTIiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODlBN0Yy'
    b'MTI3NkNCMTFFMjhFOEJDNDUxRkU5OTMzQTIiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4OUE3RjIwRjc2Q0IxMUUyOEU4QkM0NTFGRTk5MzNBMiIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4OUE3RjIxMDc2Q0IxMUUyOEU4QkM0NTFGRTk5'
    b'MzNBMiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/Pi0WmboAAAJDSURBVHjapFNNaBNBFP5mdmJD8RdME5CoYKmIFArR'
    b'qq1FwaJWBQvVgKgHD5YeBMGDB6MNie1NpYoeqngQhCKIxB9ENi2ItWADtdKggvHiQUIkKKEx'
    b'iW4z49tJU6KkFXSWt8zO7Hvv+773HlNK4X8WK2+Gw9uT9OmpOKqy7GQq1d770lM+EfbLDG5V'
    b'm4+dQ/r9Q/LnC/hLrNxw0G0Ww2p36JXOxIbDrfdau/v9mQ9PKD4HY/MjsOkySCxrOICxmwFC'
    b'MuYRdOpPfYxDKm+J0V8lkSgkpgiMdGsKjHM4apxIxSOUnWMhDRRRUHIGdRv3QxYLJRFH+tpU'
    b'0bJoyzX/+Sjoaqki5EwOvhMD9K+Ea90uJggKWroH8OnFZfIX1QPMOkMWUL83iHc3flAAS19x'
    b'G5aV+wqDsttW/QEMCrB+TxiBa8+wtNGL7ytq8TrwQJGIDOpnBoYwCIHxhwZK8wah9O7oxdmr'
    b'Jo76u3D36RDcWTea0nldNygrCyEcMAyjwigz3RlMwdvej4lLhxE4Xo/IYxM+XzMm82/RPNiz'
    b'ieuMdgDDMWuiZERHcIVVO0OIXdyHls46LJ88jUMN3xB5FEW4p8uGOKE7kckcxCLHXHdrxQm2'
    b'a9t5ZKIn0Ra4AJkhuFNnMBobwuDt5xgJdWCuD4TKA07nb/UGiU6scD/ugtdKoKNxMa6Pr8ap'
    b'WyaysSukam15Fth0LDq6RDdJRdmUVcCWtWkkkha+JMex5jPHkeAdmH2d4KLGLvl0eRqb7Cr9'
    b'wyQTRrz5JcAAGhHev5SFI9MAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

delete_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODYzRjE3Qzk3NkNC'
    b'MTFFMjgwQjhGQjU5OTExODg3MjkiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODYzRjE3'
    b'Q0E3NkNCMTFFMjgwQjhGQjU5OTExODg3MjkiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4NjNGMTdDNzc2Q0IxMUUyODBCOEZCNTk5MTE4ODcyOSIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4NjNGMTdDODc2Q0IxMUUyODBCOEZCNTk5MTE4'
    b'ODcyOSIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/Pj9gWJ8AAAIeSURBVHjajFI9aFNRFP7uz0ueDXZS2qWFLoVSlCwF'
    b'qUVMESxY0KVxcRbRLYhDB4UMOgmCDg52cZLWgkIXm0hAHfxBOoTSQWtpM5hoW2kaY2Nf7vHc'
    b'2wcJpE09cODd++73nfN95wiEkU2PFAHRxYmDg2zOnLv9Lpm7m4glJnO/tb2ev3OKhq5MYn3p'
    b'JeNlG7zBsYGLE/P1NDFY2SuVTZ+eHrl2b7Cy8gpe9AgiUZ8zum96kSiC8jf0j11HovPLwNNc'
    b'4bkG0UTpax6GeuDaJxwShB1+z7gkHy5rISVX9lHKv4Bw7bf3gFhG14lLsDgbmlFYnJviT+n0'
    b'C3EwARE5H9ZXp6A8b4+AjMHw1QdYfXOf8botwV4HAXrP3MT7J6mQgBl3q5tQrvo+EpjQXSvp'
    b'miSSCOplGC1CCSRAf7egtOKHqpVAMkFEovK6gNqnH/zcYAspdPR3NDyg3Qq09sIdaCLgT+FJ'
    b'bGfXECsYnBw7C3i8OkGAlcUlfL4w9Ei7V5ZAea1LxOTSU6h++I7B4TjoF3dgAgil0dfTjY3N'
    b'jRtuE4WpQke8Rtnm9qMsSxDE6DhwPtn4m5kGLeTh9kDTH8D3W023EiLKVQxmHoOePYSpG0g2'
    b'VPAYpVKwErY/Zt4etdOgFjz7wx7E2LDlUhV9nSzJjpJJlssBirVg1nYUt0M6bIHnRuO3umN+'
    b'kkKRxZ3a7HhmISXw/9HLebzp/JNz7Z8AAwDLYLxgFHNxHwAAAABJRU5ErkJggg==')

