#In the name of GOD
#please put your code under here
#Supervised Learning
#Regresion Problem Normal Equesion
# -*- coding: utf-8 -*-
#!usr/bin/env python

from AI.Analiz import *

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D

class CustFunction:
	def __init__(self):
		pass

	def GradientDescent(self, X, y, Theta, Alpha, NumItr):
		return 1